==> opennms-dao-14.0.2-sources.jar: org/opennms/netmgt/dao/hibernate/LldpElementDaoHibernate.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2006-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.hibernate;

import org.opennms.netmgt.dao.api.LldpElementDao;
import org.opennms.netmgt.model.LldpElement;
import org.opennms.netmgt.model.LldpElement.LldpChassisIdSubType;

import java.util.List;

public class LldpElementDaoHibernate extends AbstractDaoHibernate<LldpElement, Integer> implements LldpElementDao {

    /**
     * <p>
     * Constructor for LldpElementDaoHibernate.
     * </p>
     */
    public LldpElementDaoHibernate() {
        super(LldpElement.class);
    }

    /**
     * <p>
     * findByNodeId
     * </p>
     *
     * @param id a {@link java.lang.Integer} object.
     * @return a {@link org.opennms.netmgt.model.LldpElement} object.
     */
    @Override
    public LldpElement findByNodeId(Integer id) {
        return findUnique("from LldpElement rec where rec.node.id = ?", id);
    }

	@Override
	public List<LldpElement> findByChassisId(String chassisId, LldpChassisIdSubType type) {
        return find("from LldpElement rec where rec.lldpChassisId = ? and rec.lldpChassisIdSubType = ?", chassisId, type);
	}

	@Override
	public LldpElement findBySysname(String sysname) {
        return findUnique("from LldpElement rec where rec.lldpSysname = ?", sysname);
	}


}

==> opennms-dao-18.0.0-20160218.210947-150-sources.jar: org/opennms/netmgt/dao/hibernate/LldpElementDaoHibernate.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2006-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.hibernate;

import org.opennms.core.utils.LldpUtils.LldpChassisIdSubType;
import org.opennms.netmgt.dao.api.LldpElementDao;
import org.opennms.netmgt.model.LldpElement;

import java.util.List;

public class LldpElementDaoHibernate extends AbstractDaoHibernate<LldpElement, Integer> implements LldpElementDao {

    /**
     * <p>
     * Constructor for LldpElementDaoHibernate.
     * </p>
     */
    public LldpElementDaoHibernate() {
        super(LldpElement.class);
    }

    /**
     * <p>
     * findByNodeId
     * </p>
     *
     * @param id a {@link java.lang.Integer} object.
     * @return a {@link org.opennms.netmgt.model.LldpElement} object.
     */
    @Override
    public LldpElement findByNodeId(Integer id) {
        return findUnique("from LldpElement rec where rec.node.id = ?", id);
    }

	@Override
	public List<LldpElement> findByChassisId(String chassisId, LldpChassisIdSubType type) {
        return find("from LldpElement rec where rec.lldpChassisId = ? and rec.lldpChassisIdSubType = ?", chassisId, type);
	}

	@Override
	public LldpElement findBySysname(String sysname) {
        return findUnique("from LldpElement rec where rec.lldpSysname = ?", sysname);
	}


}
